Module string

Module string 

Enums

Case
Case variants into which the string can be recased.

Functions

recase
Recase a string into the specified case.
sanitize
Sanitize a string by removing all characters that are not alphanumeric. The only characters that are allowed are: a-z, A-Z, 0-9, _, and -. Used regex is r"[\(\)’@#<>+«»~&%^—,!\.\[\]{}\?:;·’]“`