File

Struct File 

pub struct File<'a> { /* private fields */ }
Struct to represent a file or directory. This struct is used to abstract away the underlying file system.

Implementations

Source

impl File<'_>

pub fn new(path_str: &str) -> File<'_>

Create a new file.

pub fn extension(&self) -> Option<String>

Return the file extension.

pub fn file_name(&self) -> Option<String>

Return the file name.

pub fn file_stem(&self) -> Option<String>

Return the file stem.

pub fn is_dir(&self) -> bool

Check if the file is a directory.

pub fn is_file(&self) -> bool

Check if the file is a file.

pub fn exist(&self) -> bool

Check if the file exist.

pub fn read_dir(&self) -> Result<Vec<String>, FileErr>

If File is a directory, return a vector of the files in the directory. If File is a file, return an error FileErr::NotADirectory.

pub fn create_file(&self) -> Result<(), FileErr>

Create a file. If the file already exist, an error FileErr::FileAlreadyExist will be returned.

pub fn rename(&self, new_name: &str) -> Result<(), FileErr>

Rename file or directory.

pub fn path(&self) -> String